# Results from Chapter 10 used here

# Organism package used here
load("Chapter10_V6.RData")
res2<-res[!is.na(res$padjust) & res$padjust<=0.05,]

univ<-as.character(unique(res$geneID))
deg<-as.character(unique(res2$geneID))

library(org.Hs.eg.db)
ls("package:org.Hs.eg.db")

xx <- as.list(org.Hs.egENSEMBL2EG)
xxd<-as.data.frame(unlist(xx))

head(xxd)
#                unlist(xx)
#ENSG00000121410          1
#ENSG00000175899          2
#ENSG00000256069          3
#ENSG00000171428          9
#ENSG00000156006         10
#ENSG00000196136         12

ind<-match(deg, rownames(xxd))
degeg<-as.character(xxd[ind,])

xx <- as.list(org.Hs.egGO)
ind<-match(degeg, names(xx))
degeggo<-xx[ind]

degeggo<-select(org.Hs.eg.db, degeg, "GO", keytype="ENTREZID")
degeggo<-select(org.Hs.eg.db, deg, "GO", keytype="ENSEMBL")

univ<-as.character(unique(res$geneID))
univgo<-select(org.Hs.eg.db, univ, c("CHR", "GO"), keytype="ENSEMBL")
univgo<-univgo[univgo$CHR=="18" & !is.na(univgo$CHR), c(1, 3:5)]




# BioMart used here
library("biomaRt")
listMarts()
ensembl=useMart("ensembl")
listDatasets(ensembl)
ensembl = useDataset("hsapiens_gene_ensembl",mart=ensembl)
ensembl = useMart("ensembl",dataset="hsapiens_gene_ensembl")

filters = listFilters(ensembl)
attributes = listAttributes(ensembl)

chrom<-c(18)
query<-getBM(attributes=c("ensembl_gene_id", "chromosome_name", "go_id"), filters="chromosome_name", values=list(deg, 18), mart=ensembl)
length(unique(query$ensembl_gene_id))

query<-getBM(attributes=c("ensembl_gene_id", "chromosome_name", "go_id"), filters=c("ensembl_gene_id","chromosome_name"), values=list(deg, chrom), mart=ensembl)
length(unique(query$ensembl_gene_id)) #72

query2<-getBM(attributes=c("ensembl_gene_id", "chromosome_name", "go_id"), filters=c("chromosome_name"), values=list(chrom), mart=ensembl)
length(unique(query2$ensembl_gene_id[query2$chromosome_name==18 & !is.na(query2$chromosome_name)])) #289
length(unique(query$ensembl_gene_id)) #289


# Gene set analysis
indq<-which(query$go_id=="GO:0005515")
indq2<-which(query2$go_id=="GO:0005515")
length(unique(query$ensembl_gene_id[indq]))
length(unique(query2$ensembl_gene_id[indq2]))


mat<-matrix(ncol=2, data=c(44,28,132,157))
fisher.test(mat)









# Differential analysis using edgeR
library(edgeR)
d<-DGEList(counts=counts(parathyroidGenes))
d<-d[rowSums(d$counts)>=ncol(counts(parathyroidGenes)),]
d<-calcNormFactors(d,method="TMM")   
meta <- pData(parathyroidGenes)
design <- model.matrix(~treatment+time, data=meta)
d <- estimateGLMCommonDisp(d,design)
d <- estimateGLMTrendedDisp(d,design)
d <- estimateGLMTagwiseDisp(d,design)
fit <- glmFit(d,design)
lrt <- glmLRT(fit,coef=4) # Differential expression through time 
temp <- topTags(lrt,n=100000)$table
sig.edger <- temp[temp$FDR < 0.01,]
sig.edger.names <- rownames(sig.edger)


# Competitive method
library(org.Hs.eg.db)
library(GOstats)
ensembl.to.entrez <- as.list(org.Hs.egENSEMBL2EG)
reference.genes <- unique(unlist(ensembl.to.entrez))
selected.genes<-na.omit(unique(select(org.Hs.eg.db, sig.edger.names, c("ENTREZID"), keytype="ENSEMBL")$ENTREZID))
params <- new('GOHyperGParams', geneIds=selected.genes, universeGeneIds=reference.genes, annotation='org.Hs.eg.db', ontology='BP', pvalueCutoff=0.01, conditional=TRUE, testDirection="over")
go <- hyperGTest(params)
go.table <- summary(go, pvalue=2)
go.table.sig<-go.table[go.table$Pvalue<=0.01,]


# Self-contained method
library(edgeR)
library(limma)
nf <- calcNormFactors(counts(parathyroidGenes))
y <- voom(counts(parathyroidGenes), design, plot=TRUE, lib.size=colSums(counts(parathyroidGenes))*nf)

library(globaltest)
gt.options(transpose=TRUE)
go2<-gtGO(meta$time, y$E, ontology="BP", annotation="org.Hs.eg.db", probe2entrez=as.list(ensembl.to.entrez))
go2<-gtGO(meta$time, y$E, ontology="BP", annotation="org.Hs.eg.db", probe2entrez=as.list(ensembl.to.entrez), multtest="BH")
go2.table.sig<-go2@result[go2@result[,1]<=0.01,]

# Lenght corrected
gene.vector<-as.numeric(reference.genes %in% selected.genes)
names(gene.vector)<-reference.genes
library(goseq)
pwf=nullp(gene.vector,"hg19","knownGene")
GO.wall=goseq(pwf,"hg19","knownGene", test.cats=c("GO:BP"))
GO.wall$padj<-p.adjust(GO.wall$over_represented_pvalue, method="BH")
go3.table.sig<-GO.wall[GO.wall$padj<=0.01,]







# lenght bias
library(goseq)







