# Object S3/S4 classes
library(GenomicRanges)
read<-GRanges(seqnames=c("19"), ranges=IRanges(start=c(44047464), end=c(44047499)), strand=c("+"), seqlenghts=c("19"=59128983))
strand(read)
width(read)
names(read)<-c("XRCC1")
read.df<-as.data.frame(read)


# Constructing a count table
generateCountTable <- function(files, transcripts="TxDb.Hsapiens.UCSC.hg19.knownGene", overlapto="gene") {
   require(transcripts, character.only=TRUE)
   require(GenomicRanges)
   require(Rsamtools)
   txdb<-transcriptsBy(get(transcripts, envir=.GlobalEnv), overlapto)
   l<-vector("list", length(files))
   for(i in 1:length(files)) {
      alns <- readGappedAlignments(files[i])
      strand(alns) <- "*"
      hits <- countOverlaps(alns, txdb)
      l[[i]]<- countOverlaps(txdb, alns[hits==1])
      names(l)<-gsub("\\.bam", "", files)
   }
   ct<-as.data.frame(l)
   ct   
}
counttable<-generateCountTable(dir(pattern=".bam"))



# Mapping and generating count tables
library(Rsamtools)
p2 <- ScanBamParam(what=c("rname", "strand", "pos", "qwidth", "seq"))
h1b<-readBamGappedAlignments("hESC1_chr18.bam", param=p2)
library(BSgenome.Hsapiens.UCSC.hg19)
chr18<-(BSgenome.Hsapiens.UCSC.hg19[["chr18"]])
seqs<-mcols(h1b)$seq
seqs2<-seqs[100:1100,]
mpd<-matchPDict(seqs2, chr18)
mpd2<-as(mpd, "CompressedIRangesList")
mpd3<-as(RangedData(mpd2), "GRanges")
library(TxDb.Hsapiens.UCSC.hg19.knownGene)
txdb<-transcriptsBy(TxDb.Hsapiens.UCSC.hg19.knownGene, "gene")
txdb_chr18<-keepSeqlevels(txdb, "chr18")
gr<-GRanges(seqnames=Rle(rep("chr18", length(mpd3))),
            ranges=mpd3@ranges,
            strand=strand(mpd3),
            seqinfo=Seqinfo("chr18", 78077248)
            )
hits <- countOverlaps(gr, txdb_chr18)
ol<-countOverlaps(txdb, gr[hits==1])
table(ol)



# Take SNPs into account
library(BSgenome.Hsapiens.UCSC.hg19)
library(SNPlocs.Hsapiens.dbSNP.20120608_0.99.9)
genome <- injectSNPs(BSgenome.Hsapiens.UCSC.hg19, "SNPlocs.Hsapiens.dbSNP.20120608")
chr18<-(BSgenome.Hsapiens.UCSC.hg19[["chr18"]])
library(TxDb.Hsapiens.UCSC.hg19.knownGene)
txdb<-transcriptsBy(TxDb.Hsapiens.UCSC.hg19.knownGene, "gene")
txdb_chr18<-keepSeqlevels(txdb, "chr18")


p2 <- ScanBamParam(what=c("rname", "strand", "pos", "qwidth", "seq"))
h1b<-readBamGappedAlignments("hESC1_chr18.bam", param=p2)
seqs<-mcols(h1b)$seq
seqs2<-seqs[100:1100,]
system.time(mpd<-matchPDict(seqs2, chr18, fixed="pattern"))
mpd<-matchPDict(seqs2, chr18)
mpd2<-as(mpd, "CompressedIRangesList")
mpd3<-as(RangedData(mpd2), "GRanges")
gr<-GRanges(seqnames=Rle(rep("chr18", length(mpd3))),
            ranges=mpd3@ranges,
            strand=strand(mpd3),
            seqinfo=Seqinfo("chr18", 78077248)
            )
hits <- countOverlaps(gr, txdb_chr18)
ol<-countOverlaps(txdb, gr[hits==1])
table(ol)


# Generating new annotation packages
# Transcripts
library(AnnotationForge)
makeOrgPackageFromNCBI(version = "0.1",
                       author = "Jarno Tuimala <jtuimala@gmail.com>",
                       maintainer = "Jarno Tuimala <jtuimala@gmail.com>",
                       outputDir = "C:/Users/Jarno Tuimala/Desktop/alpaca",
                       tax_id = "30538",
                       genus = "Vicugna",
                       species = "pacos")
install.packages(pkgs="C:\\Users\\Jarno Tuimala\\Desktop\\alpaca\\org.Vpacos.eg.db", lib="C:\\Users\\Jarno Tuimala\\Documents\\R\\win-library\\3.0", type="source", repos="NULL")

# Transcript package
library(GenomicFeatures)
#supportedUCSCtables()
txdb <- makeTranscriptDbFromUCSC(genome="vicPac2", tablename="xenoRefGene")
makeTxDbPackage(txdb,
                version="0.1",
                maintainer="Jarno Tuimala <jtuimala@gmail.com>",
                author="Jarno Tuimala <jtuimala@gmail.com>",
                destDir="C:/Users/Jarno Tuimala/Desktop/alpaca",
                license="Artistic-2.0")
# 
