# Set the working directory to where the data is located
setwd(choose.dir())

# Loads the library
library(DEXSeq)

# Loads the extra functions
# Select the Chapter10-extra.R file
source(file.choose())

# Load the example data (ENCODE)
# Option 1
samplename<-c("Gm12892_1", "Gm12892_2", "Gm12892_3", "hESC_1", "hESC_2", "hESC_3", "hESC_4")
condition<-c("gm", "gm", "gm", "esc", "esc", "esc", "esc")
phenodata<-data.frame(samplename, condition)
rownames(phenodata)<-c("gm1","gm2","gm3","h1","h2","h3","h4")
ec<-read.HTSeqCounts(countfiles=c("gm1.txt","gm2.txt","gm3.txt","h1.txt","h2.txt","h3.txt","h4.txt"), design=phenodata)

# Option 2
# This is only needed for preparing the annotation data, and a sigle pass is enough
# This generates the annottable.txt file
# Uses the gtf-file from the Ensembl service
gtf<-read.table("Homo_sapiens.GRCh37.70.gtf", header=F, sep="\t")
write.table(gtf[,9, drop=F], "gtf-annot.txt", row.names=F, col.names=F, sep="\t", quote=F)
gtf2<-read.table("gtf-annot.txt", header=F, sep=";", fill=TRUE, comment.char="", quote="")
gtf$V9<-gsub("gene_id ", "", gtf2$V1)
gtf$V10<-formatC(as.numeric(gsub(" ", "", gsub("exon_number ", "", gtf2$V3))), width=3, flag="0", format="fg")
gtf<-cbind(gtf, gtf2)
gtf$names=gsub(" ", "", paste(gtf$V9, gtf$V10, sep=":"))
gtf.f<-gtf[gtf$V3=="exon" & gtf$V2=="protein_coding",]
gtf.f2<-gtf.f[order(gtf.f[,19], gtf.f[,16]),]
gtf.f2$trans<-gsub("transcript_name ", "", gtf.f2[,16])
gtf.f2$trans<-gsub(" ", "", gtf.f2$trans)
gtf.f3<-gtf.f2[!duplicated(gtf.f2$names),]
df<-data.frame(notr=table(gtf.f2$names))
fun<-function(x) {
   paste(paste("a", 1:x, sep=""), collapse=";")
}
res<-apply(df[,2,drop=F], MARGIN=1, FUN=fun) 
gtf.f3$transcripts<-res
annottable<-data.frame(chr="chr18", start=gtf.f3[,4], end=gtf.f3[,5], strand=gtf.f3[,7], transcript=gtf.f3$transcript)
annottable$names<-gtf.f3$names
dat<-read.table("ENCODE_ngs-data-table_exons.tsv", header=T, sep="\t")
dat$names<-paste(substr(geneids, 1, 15), exonids, sep=":")
dat$order<-1:nrow(dat)
d<-merge(dat, annottable, by.x="names", by.y="names", sort=FALSE, all.x=TRUE)
d2<-d[order(d$order),]
d2$chr<-"chr18"
write.table(d2[,10:14], "annottable.txt", sep="\t", col.names=F, row.names=F, quote=F)

# This actually loads the experimental data
dat<-read.table("ENCODE_ngs-data-table_exons.tsv", header=T, sep="\t")
samplename<-c("Gm12892_1", "Gm12892_2", "Gm12892_3", "hESC_1", "hESC_2", "hESC_3", "hESC_4")
condition<-c("gm", "gm", "gm", "esc", "esc", "esc", "esc")
phenodata<-data.frame(samplename, condition)
rownames(phenodata)<-c("gm1","gm2","gm3","h1","h2","h3","h4")
nc<-nchar(rownames(dat))
geneids<-substr(rownames(dat), 1, nc-4)
exonids<-substr(rownames(dat), nc-2, nc)
annot<-read.table("annottable.txt", header=F, sep="\t")
annot2<-annot[,1:4]
colnames(annot2)<-c("chr", "start", "end", "strand")
rownames(annot2)<-rownames(dat)
transcripts<-as.character(annot[,5])
library(DEXSeq)
ec<-newExonCountSet(dat, phenodata, geneids, exonids, annot2, transcripts)

# The next code does the actual analysis
ec<-estimateSizeFactors(ec)
ec<-estimateDispersions(ec)
ec<-fitDispersionFunction(ec)
ec<-testForDEU(ec)
ec<-estimatelog2FoldChanges(ec)
res<-DEUresultTable(ec)
res2<-res[!is.na(res$padjust),]
plotDEXSeqSimple(ec, "ENSG00000226742")
plotDEXSeqSimple(ec, "ENSG00000074657")
plotDEXSeqSimple(ec, "ENSG00000119541", legend=TRUE)
DEXSeqHTML(ecs, as.character(unique(res[ind,1])))
